==> haskell-js-dgtable-0.5.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-dgtable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-dgtable
version:              0.5.2
visibility:           public
id:                   js-dgtable-0.5.2-BP8cvX2EPWg5MI68SZQi3j
key:                  js-dgtable-0.5.2-BP8cvX2EPWg5MI68SZQi3j
license:              MIT
copyright:            Neil Mitchell 2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-dgtable#readme
synopsis:             Obtain minified jquery.dgtable code
description:
    This package bundles the minified <https://github.com/danielgindi/jquery.dgtable jquery.dgtable> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jquery.dgtable version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  b389308aa6ca6ec3f175272851fde870
exposed:              True
exposed-modules:      Language.Javascript.DGTable
hidden-modules:       Paths_js_dgtable
import-dirs:          /usr/lib/ghc-9.0.2/site-local/js-dgtable-0.5.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/js-dgtable-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/js-dgtable-0.5.2
hs-libraries:         HSjs-dgtable-0.5.2-BP8cvX2EPWg5MI68SZQi3j
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-js-dgtable/html/js-dgtable.haddock
haddock-html:         /usr/share/doc/haskell-js-dgtable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-dgtable-0.5.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-dgtable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-dgtable
version:              0.5.2
visibility:           public
id:                   js-dgtable-0.5.2-9QcYNIrannTBnclkJddG4d
key:                  js-dgtable-0.5.2-9QcYNIrannTBnclkJddG4d
license:              MIT
copyright:            Neil Mitchell 2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-dgtable#readme
synopsis:             Obtain minified jquery.dgtable code
description:
    This package bundles the minified <https://github.com/danielgindi/jquery.dgtable jquery.dgtable> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jquery.dgtable version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  3af3752b743b817bef2803a3cd1af853
exposed:              True
exposed-modules:      Language.Javascript.DGTable
hidden-modules:       Paths_js_dgtable
import-dirs:          /usr/lib/ghc-9.2.8/site-local/js-dgtable-0.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/js-dgtable-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-dgtable
hs-libraries:         HSjs-dgtable-0.5.2-9QcYNIrannTBnclkJddG4d
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-js-dgtable/html/js-dgtable.haddock
haddock-html:         /usr/share/doc/haskell-js-dgtable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
